==> moodle-1.5-mysql.tgz: moodle/lang/th/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.6 development (2005052400)


$string['admindirerror'] = 'á admin к١ͧ';
$string['admindirname'] = 'á admin';
$string['admindirsetting'] = 'ʵӹǹ· /admin  㹡õԴкǺ䫵 繪ǡѺ˹Ҽк moodle  Ըա§ѭҤس¹ admin  Moodle 繪ҧõԴ ͧõҧ moodleadmin';
$string['caution'] = '͹';
$string['chooselanguage'] = '͡';
$string['compatibilitysettings'] = 'Ǩͺõ駤 PHP';
$string['configfilenotwritten'] = 'ǵԴѵѵöҧ config.php  Ҩö¹ŧá moodle  سöҧѧͧ¡áͻ鴵仹ŧͧҧ';
$string['configfilewritten'] = 'ҧ config.php º';
$string['configurationcomplete'] = '駤ҵ';
$string['database'] = 'ҹ';
$string['databasesettings'] = 'س繵ͧ駤Ұҹŷ㹡红Ţͧ moodle ҹŴѧǨеͧաҧǧ˹ 
<br /> <br />

<b>:</b> mysql  postgres7<br />

<b>ʵ:</b>   localhost  db.isp.com<br />

<b>Ͱҹ:</b> Ͱҹ, moodle<br />

<b>ͼ (username):</b> username ͧҹ<br />

<b>ʼҹ:</b> ʼҹҰҹ<br />

<b>ӹ˹ҵҧ:</b> ӹ˹ҵҧ ջªҡհҹŢͧ¡͡ ҧ繢ͧ  mdl_';
$string['dataroot'] = 'áբ';
$string['datarooterror'] = '辺áբŷسкöҧ س Path ١ͧҧáչ';
$string['dbconnectionerror'] = 'öԴͰҹŷسк سҵǨͺҷͧҹ';
$string['dbcreationerror'] = 'բͼԴҴ㹡ҧҹ öҧҹŷкش¤ҷ';
$string['dbhost'] = 'ʵ';
$string['dbpass'] = 'ʼҹ';
$string['dbprefix'] = 'ӹ˹ҵҧ (Table Prefix)';
$string['dbtype'] = '';
$string['directorysettings'] = '<p>س׹ѹ駢ͧõԴ  Moodle .</p>

<p><b>ͧ (Web Address):</b>

кطͧ䫵سй Moodle  ҡ红ͧسҼҹ URLs ¢͡ѡ¹ͧس ͧͧ /  Դ</p>

<p><b>á moodle </b>

к path ͧá  㹡õԴ ѧͧ͵Ǿ˭ Ҷ١ͧ </p>

<p><b>áբ:</b>

áչ繷 moodle зӡúѹ֡ 繢Ţͧ ѧ鹤Է㹡ҹ  ¹ŧáչ  ( \'nobody\'  \'apache\') 仵ç  ҹ
</p>';
$string['dirroot'] = 'Moodle á';
$string['dirrooterror'] = 'õ駤 á moodle ١ͧ 辺Դ駷к  кӡ絤Ҵҹҧ ';
$string['download'] = 'ǹŴ';
$string['fail'] = '';
$string['fileuploads'] = 'ѾŴ';
$string['fileuploadserror'] = 'èԴ(on)';
$string['fileuploadshelp'] = '<p>ѾŴ</p>

<p>سöԴ Moodle ֧ҹѧա͹حҵöѾŴ㹴  ٻҾСͺѵǹǢͧҪԡ</p>

<p>ԴͧҹӡԴ ѾŴ觻Է  php.ini ¹ <b>file_uploads</b> \'1\'.</p>';
$string['gdversion'] = 'GD  ѹ';
$string['gdversionerror'] = 'ա GD library ͷ';
$string['gdversionhelp'] = '<p>ͧسѧաõԴ GD </p>

<p>GD ǹ㹡ê㹡ʴлżٻҾҧ   Moodle ҷ Ҿͤ͹㹻ѵǹ СҧҾ蹡ûǼšҿͧѹ֡ҹ䫵ҧ  ҧáسѧö Moodle ֧ GD ԴöҹǡѺʴлżҾҹ</p>

<p> õԴ GD  PHP ٹԡ   --with-gd</p>

<p>ǹҹԹسöԴ¡  php.ini ͧ¤ҹ˹ libgd.dll ͡</p>';
$string['installation'] = 'õԴ';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'èлԴ (off)';
$string['magicquotesruntimehelp'] = '<p>÷ӡûԴ Magic quotes runtime  moodle ӧҹ١ͧ</p>

<p>·зӡûԴҹ͹ öҡõ駤ҵ <b>magic_quotes_runtime</b>  php.ini </p>

<p>Ҥسö php.ini µͧسöӡûԴѧ蹹¡ .htaccess á moodle ҧաõ駤Ҵѧ

<blockquote>php_value magic_quotes_runtime Off</blockquote>

</p> ';
$string['memorylimit'] = '٧ش (Memory Limit)';
$string['memorylimiterror'] = '٧شس͹ҧ Ҩջѭѧ';
$string['memorylimithelp'] = '<p>Ҥ٧شͧͧس  $a</p>

<p>Ӵѧդҹ令Ҩջѭ㹡ҹ moodle ѧ੾ͤس  件֧Ҫԡӹǹҡ</p>

<p>ҷõҡشҷҡ ҷй 16M Ը㹡Ҥ٧ش Ǥ:</p>

<ol>

<li>դ PHP   <i>--enable-memory-limit</i> 繡õ駤 moodle ˹մӡѴ٧شͧ </li>

<li>Ҥسö  php.ini µͧö¹ <b>memory_limit</b> 繤  16M ö¹ҹµͧ駼к</li>

<li> PHP ҧǤسöҧ  .htaccess á moodle պ÷Ѵ仹:

<p><blockquote>php_value memory_limit 16M</blockquote></p>

<p>ҧá㹺ҧسö Ըչ ¨աʴ error Ҥس繵ͧźѧǹ </p></li>
</ol>';
$string['mysqlextensionisnotpresentinphp'] = 'õ駤  PHP Ѻ MySQL ١ͧسҵǨͺ php.ini ադ php';
$string['pass'] = '';
$string['phpversion'] = 'PHP ѹ';
$string['phpversionerror'] = 'ѹͧ PHP ҧ 4.1.0';
$string['phpversionhelp'] = '<p>Moodle 繵ͧ PHP ѹ 4.1.0 ҧ</p>

<p>سѧѹ $a</p>

<p>سͧѾô  PHP ʵ PHP ѹ</p>';
$string['safemode'] = 'Safe Mode';
$string['safemodeerror'] = 'moodle Ҩջѭҡ safe mode on';
$string['safemodehelp'] = '<p>Moodle Ҩջѭҡ safe mode on 觨зسöҧ</p>

<p>Safe mode ·ǨԴ㹺ҧʵ Ҩ繵ͧʵѺҹ Moodle </p>

<p>سöõԴ㹵͹Ҩջѭҵѧ</p>';
$string['sessionautostart'] = 'Session Auto Start';
$string['sessionautostarterror'] = 'èлԴ (off)';
$string['sessionautostarthelp'] = '<p>Moodle зӧҹʹѺʹع session </p>

<p>سö Sessions ӧҹ¡  php.ini   session.auto_start </p>';
$string['wwwroot'] = 'ͧ';
$string['wwwrooterror'] = 'ͧ١ͧ к辺 Moodle ';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/th/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.4.2 (2004083125)


$string['admindirerror'] = 'á admin к١ͧ';
$string['admindirname'] = 'á admin';
$string['admindirsetting'] = 'ʵӹǹ· /admin  㹡õԴкǺ䫵 繪ǡѺ˹Ҽк moodle  Ըա§ѭҤس¹ admin  Moodle 繪ҧõԴ ͧõҧ moodleadmin';
$string['caution'] = '͹';
$string['chooselanguage'] = '͡';
$string['compatibilitysettings'] = 'Ǩͺõ駤 PHP';
$string['configfilenotwritten'] = 'ǵԴѵѵöҧ config.php  Ҩö¹ŧá moodle  سöҧѧͧ¡áͻ鴵仹ŧͧҧ';
$string['configfilewritten'] = 'ҧ config.php º';
$string['configurationcomplete'] = '駤ҵ';
$string['database'] = 'ҹ';
$string['databasesettings'] = 'س繵ͧ駤Ұҹŷ㹡红Ţͧ moodle ҹŴѧǨеͧաҧǧ˹ 
<br /><br />

<b>:</b> mysql  postgres7<br />

<b>ʵ:</b>   localhost  db.isp.com<br />

<b>Ͱҹ:</b> Ͱҹ, moodle<br />

<b>ͼ (username):</b> username ͧҹ<br />

<b>ʼҹ:</b> ʼҹҰҹ<br />

<b>ӹ˹ҵҧ:</b> ӹ˹ҵҧ ջªҡհҹŢͧ¡͡ ҧ繢ͧ  mdl_';
$string['dataroot'] = 'áբ';
$string['datarooterror'] = '辺áբŷسкöҧ س Path ١ͧҧáչ';
$string['dbconnectionerror'] = 'öԴͰҹŷسк سҵǨͺҷͧҹ';
$string['dbcreationerror'] = 'բͼԴҴ㹡ҧҹ öҧҹŷкش¤ҷ';
$string['dbhost'] = 'ʵ';
$string['dbpass'] = 'ʼҹ';
$string['dbprefix'] = 'ӹ˹ҵҧ (Table Prefix)';
$string['dbtype'] = '';
$string['directorysettings'] = '<p>س׹ѹ駢ͧõԴ  Moodle .</p>

<p><b>ͧ (Web Address):</b>

кطͧ䫵سй Moodle  ҡ红ͧسҼҹ URLs ¢͡ѡ¹ͧس ͧͧ /  Դ</p>

<p><b>á moodle </b>

к path ͧá  㹡õԴ ѧͧ͵Ǿ˭ Ҷ١ͧ </p>

<p><b>áբ:</b>

áչ繷 moodle зӡúѹ֡ 繢Ţͧ ѧ鹤Է㹡ҹ  ¹ŧáչ  ( \'nobody\'  \'apache\') 仵ç  ҹ
</p>';
$string['dirroot'] = 'Moodle á';
$string['dirrooterror'] = 'õ駤 á moodle ١ͧ 辺Դ駷к  кӡ絤Ҵҹҧ ';
$string['download'] = 'ǹŴ';
$string['fail'] = '';
$string['fileuploads'] = 'ѾŴ';
$string['fileuploadserror'] = 'èԴ(on)';
$string['fileuploadshelp'] = '<p>ѾŴ</p>

<p>سöԴ Moodle ֧ҹѧա͹حҵöѾŴ㹴  ٻҾСͺѵǹǢͧҪԡ

<p>ԴͧҹӡԴ ѾŴ觻Է  php.ini ¹ <b>file_uploads</b> \'1\'.</p>';
$string['gdversion'] = 'GD  ѹ';
$string['gdversionerror'] = 'ա GD library ͷ';
$string['gdversionhelp'] = '<p>ͧسѧաõԴ GD </p>

<p>GD ǹ㹡ê㹡ʴлżٻҾҧ   Moodle ҷ Ҿͤ͹㹻ѵǹ СҧҾ蹡ûǼšҿͧѹ֡ҹ䫵ҧ  ҧáسѧö Moodle ֧ GD ԴöҹǡѺʴлżҾҹ</p>

<p> õԴ GD  PHP ٹԡ   --with-gd</p>

<p>ǹҹԹسöԴ¡  php.ini ͧ¤ҹ˹ libgd.dll ͡</p>';
$string['installation'] = 'õԴ';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'èлԴ (off)';
$string['magicquotesruntimehelp'] = '<p>÷ӡûԴ Magic quotes runtime  moodle ӧҹ١ͧ</p>

<p>·зӡûԴҹ͹ öҡõ駤ҵ <b>magic_quotes_runtime</b>  php.ini </p>

<p>Ҥسö php.ini µͧسöӡûԴѧ蹹¡ .htaccess á moodle ҧաõ駤Ҵѧ

<blockquote>php_value magic_quotes_runtime Off</blockquote>

</p> ';
$string['memorylimit'] = '٧ش (Memory Limit)';
$string['memorylimiterror'] = '٧شس͹ҧ Ҩջѭѧ';
$string['memorylimithelp'] = '<p>Ҥ٧شͧͧس  $a</p>

<p>Ӵѧդҹ令Ҩջѭ㹡ҹ moodle ѧ੾ͤس  件֧Ҫԡӹǹҡ

<p>ҷõҡشҷҡ ҷй 16M Ը㹡Ҥ٧ش Ǥ:

<ol>

<li>դ PHP   <i>--enable-memory-limit</i> 繡õ駤 moodle ˹մӡѴ٧شͧ 

<li>Ҥسö  php.ini µͧö¹ <b>memory_limit</b> 繤  16M ö¹ҹµͧ駼к

<li> PHP ҧǤسöҧ  .htaccess á moodle պ÷Ѵ仹:

<p><blockquote>php_value memory_limit 16M</blockquote></p>

<p>ҧá㹺ҧسö Ըչ ¨աʴ error Ҥس繵ͧźѧǹ 
</ol>';
$string['mysqlextensionisnotpresentinphp'] = 'õ駤  PHP Ѻ MySQL ١ͧسҵǨͺ php.ini ադ php';
$string['parentlanguage'] = 'en';
$string['pass'] = '';
$string['phpversion'] = 'PHP ѹ';
$string['phpversionerror'] = 'ѹͧ PHP ҧ 4.1.0';
$string['phpversionhelp'] = '<p>Moodle 繵ͧ PHP ѹ 4.1.0 ҧ</p>

<p>سѧѹ $a</p>

<p>سͧѾô  PHP ʵ PHP ѹ</p>';
$string['safemode'] = 'Safe Mode';
$string['safemodeerror'] = 'moodle Ҩջѭҡ safe mode on';
$string['safemodehelp'] = '<p>Moodle Ҩջѭҡ safe mode on 觨зسöҧ</p>

<p>Safe mode ·ǨԴ㹺ҧʵ Ҩ繵ͧʵѺҹ Moodle </p>

<p>سöõԴ㹵͹Ҩջѭҵѧ</p>';
$string['sessionautostart'] = 'Session Auto Start';
$string['sessionautostarterror'] = 'èлԴ (off)';
$string['sessionautostarthelp'] = '<p>Moodle зӧҹʹѺʹع session </p>

<p>سö Sessions ӧҹ¡  php.ini   session.auto_start </p>';
$string['thischarset'] = 'TIS-620';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Thai';
$string['wwwroot'] = 'ͧ';
$string['wwwrooterror'] = 'ͧ١ͧ к辺 Moodle ';

?>
